function y = lambdak(u,k);
%   k's lambda functions for pseudoAW
%
%   Computes the parametrizing function lambdak defining the Affine Wigner
%   distributions.
%
%   1.  Usage
%
%   [y] = lambdak(u,k)
%
%   1.1.  Input parameters
%
%   o  u : real vector [1,n]
%      Argument of the function lambdak.
%
%   o  k : real scalar
%      Parameter of the lambdak function. K=-1 corresponds to the
%      Unterberger  distribution; K=0 corresponds to the  Bertrand
%      distribution; K=0.5 corresponds to the  D-Flandrin  distribution;
%      K=2 corresponds to the  Wigner-Ville  distribution on analytic
%      signals.
%
%   1.2.  Output parameters
%
%   o  y : real vector [1,n]
%      Result of the function  lambdak .
%
%   2.  See also:
%
%   pseudoAW
%
%   3.  Examples
%
%   x = linspace(-5,5,101) ;
%   y0 = lambdak(x,-1) ;
%   y1 = lambdak(x,2) ;
%   plot(x,y0,x,y1) ; axis([-5 5 0 10])
%   xlabel('time') ; title('\lambda_{k}(x) ; k = -1 ; 2') ;
%   legend('k=-1','k=2') ;

% Author Paulo Goncalves, June 1997

% FracLab 2.05 Beta, Copyright  1996 - 2009 by INRIA
% -- --
% For details on use and redistribution refer to $fraclab/licence.txt
%--------------------------------------------------------------------------

if (k~=0) & (k~=1)
  ind = find(u ~= 0) ;
  y = ones(size(u)) ;
  y(ind) = (k*(exp(-u(ind))-1)./(exp(-k*u(ind))-1)).^(1/(k-1)) ;
elseif k==0
  ind = find(u ~= 0) ;
  y = ones(size(u)) ;
  y(ind) = -u(ind)./(exp(-u(ind))-1) ;
elseif k==1
  ind = find(u ~= 0) ;
  y = ones(size(u)) ;
  y(ind) = exp(1+u(ind).*exp(-u(ind))./(exp(-u(ind))-1)) ;
end;
